# xoxys.dockerengine

[![Build Status](https://ci.rknet.org/api/badges/ansible/xoxys.dockerengine/status.svg)](https://ci.rknet.org/repos/ansible/xoxys.dockerengine)
[![License: MIT](https://img.shields.io/badge/license-MIT-blue.svg)](https://gitea.rknet.org/ansible/xoxys.dockerengine/src/branch/main/LICENSE)

Setup docker engine.

## Table of content

- [Requirements](#requirements)
- [Default Variables](#default-variables)
  - [dockerengine_daemon_config](#dockerengine_daemon_config)
  - [dockerengine_daemon_config_extra](#dockerengine_daemon_config_extra)
  - [dockerengine_http_proxy](#dockerengine_http_proxy)
  - [dockerengine_https_proxy](#dockerengine_https_proxy)
  - [dockerengine_networks](#dockerengine_networks)
  - [dockerengine_networks_extra](#dockerengine_networks_extra)
  - [dockerengine_no_proxy](#dockerengine_no_proxy)
  - [dockerengine_nsremap_range_length](#dockerengine_nsremap_range_length)
  - [dockerengine_nsremap_range_start](#dockerengine_nsremap_range_start)
  - [dockerengine_nsremap_user](#dockerengine_nsremap_user)
  - [dockerengine_packages](#dockerengine_packages)
  - [dockerengine_registries](#dockerengine_registries)
  - [dockerengine_service](#dockerengine_service)
  - [dockerengine_service_override_unit](#dockerengine_service_override_unit)
  - [dockerengine_usernamespace_enabled](#dockerengine_usernamespace_enabled)
- [Dependencies](#dependencies)
- [License](#license)
- [Author](#author)

---

## Requirements

- Minimum Ansible version: `2.10`

## Default Variables

### dockerengine_daemon_config

#### Default value

```YAML
dockerengine_daemon_config:
  selinux-enabled: false
  log-driver: journald
  log-level: info
  live-restore: true
```

### dockerengine_daemon_config_extra

#### Default value

```YAML
dockerengine_daemon_config_extra: {}
```

#### Example usage

```YAML
dockerengine_daemon_config_extra:
  userns-remap: "{{ dockerengine_nsremap_user +':' + dockerengine_nsremap_user }}"
```

### dockerengine_http_proxy

#### Default value

```YAML
dockerengine_http_proxy: _unset_
```

### dockerengine_https_proxy

#### Default value

```YAML
dockerengine_https_proxy: _unset
```

### dockerengine_networks

List of extra docker networks to create. For configuration detials see `docker_networks`.

#### Default value

```YAML
dockerengine_networks: []
```

#### Example usage

```YAML
dockerengine_networks:
  - name: my_network
    driver: bridge
    enable_ipv6: True
    ipam_config:
      - subnet: fdd1:ac8c:0557:7ce1::/64
    force: False
    state: present
```

### dockerengine_networks_extra

#### Default value

```YAML
dockerengine_networks_extra: []
```

### dockerengine_no_proxy

#### Default value

```YAML
dockerengine_no_proxy: _unset_
```

### dockerengine_nsremap_range_length

#### Default value

```YAML
dockerengine_nsremap_range_length: 65536
```

### dockerengine_nsremap_range_start

#### Default value

```YAML
dockerengine_nsremap_range_start: 231072
```

### dockerengine_nsremap_user

#### Default value

```YAML
dockerengine_nsremap_user: dockremap
```

### dockerengine_packages

#### Default value

```YAML
dockerengine_packages:
  - docker-ce
  - docker-ce-cli
  - containerd.io
```

### dockerengine_registries

List of docker registries to auto login

#### Default value

```YAML
dockerengine_registries: []
```

#### Example usage

```YAML
dockerengine_registries:
  - registry: myregistry.example.com (optional)
    username: docker
    password: secure
    reauthorize: False
    state: present
```

### dockerengine_service

#### Default value

```YAML
dockerengine_service: docker
```

### dockerengine_service_override_unit

Multiline string of options to add to the `systemd` service override unit section.

#### Default value

```YAML
dockerengine_service_override_unit: _unset_
```

#### Example usage

```YAML
dockerengine_service_override_unit: |
  After=time-sync.target
  Requires=time-sync.target
```

### dockerengine_usernamespace_enabled

#### Default value

```YAML
dockerengine_usernamespace_enabled: false
```

## Dependencies

None.

## License

MIT

## Author

[Robert Kaussow](https://gitea.rknet.org/xoxys)
